@@ -160,14 +160,13 @@ gcm_calibrate_argyll_get_display (const gchar *output_name,
 {
 	gboolean ret = FALSE;
 	gchar *command = NULL;
-	const gchar *data;
-	gchar *data_stderr = NULL;
-	gchar *data_stdout = NULL;
+	gchar *data = NULL;
 	gchar *name;
 	gchar **split = NULL;
 	gint exit_status;
 	guint display = G_MAXUINT;
 	guint i;
+	const gchar *argv[] = { "dispcal", NULL };
 
 	/* get correct name of the command */
 	command = gcm_calibrate_argyll_get_tool_filename ("dispcal", error);
@@ -175,27 +174,19 @@ gcm_calibrate_argyll_get_display (const gchar *output_name,
 		goto out;
 
 	/* execute it and capture stderr */
-	ret = g_spawn_command_line_sync (command,
-					 &data_stdout,
-					 &data_stderr,
-					 &exit_status,
-					 error);
+	argv[0] = command;
+	ret = g_spawn_sync (NULL,
+			    (gchar **) argv,
+			    NULL,
+			    G_SPAWN_STDERR_TO_DEV_NULL,
+			    NULL, NULL,
+			    &data,
+			    NULL,
+			    &exit_status,
+			    error);
 	if (!ret)
 		goto out;
 
-	/* recent versions of dispcal switched to stderr output */
-	if (data_stdout != NULL && data_stdout[0] != '\0') {
-		data = data_stdout;
-	} else if (data_stderr != NULL && data_stderr[0] != '\0') {
-		data = data_stderr;
-	} else {
-		g_set_error_literal (error,
-				     GCM_CALIBRATE_ERROR,
-				     GCM_CALIBRATE_ERROR_INTERNAL,
-				     "no sensible output from dispcal");
-		goto out;
-	}
-
 	/* split it into lines */
 	split = g_strsplit (data, "\n", -1);
 	for (i=0; split[i] != NULL; i++) {
@@ -225,8 +216,7 @@ gcm_calibrate_argyll_get_display (const gchar *output_name,
 	}
 out:
 	g_free (command);
-	g_free (data_stdout);
-	g_free (data_stderr);
+	g_free (data);
 	g_strfreev (split);
 	return display;
 }
@@ -694,7 +684,6 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 	g_ptr_array_add (array, g_strdup_printf ("-C%s", copyright));
 	g_ptr_array_add (array, g_strdup (gcm_calibrate_argyll_get_quality_arg (calibrate_argyll)));
 	g_ptr_array_add (array, g_strdup ("-aG"));
-	g_ptr_array_add (array, g_strdup ("-Zp"));
 	g_ptr_array_add (array, g_strdup (basename));
 	argv = gcm_utils_ptr_array_to_strv (array);
 	gcm_calibrate_argyll_debug_argv (command, argv);
@@ -1753,6 +1742,7 @@ gcm_calibrate_argyll_printer (GcmCalibrate *calibrate,
 
 	/* page setup, and then we're done */
 	if (print_kind == GCM_CALIBRATE_PRINT_KIND_GENERATE) {
+		const gchar *argv[] = { BINDIR "/nautilus", "", NULL };
 
 		/* get the paper size */
 		paper_size = gcm_calibrate_argyll_get_paper_size (calibrate, window);
@@ -1773,9 +1763,15 @@ gcm_calibrate_argyll_printer (GcmCalibrate *calibrate,
 		if (!ret)
 			goto out;
 
-		cmdline = g_strdup_printf ("nautilus \"%s\"", working_path);
-		g_debug ("we need to open the directory we're using: %s", cmdline);
-		ret = g_spawn_command_line_async (cmdline, error);
+		g_debug ("we need to open the directory we're using: %s", working_path);
+		argv[1] = working_path;
+		ret = g_spawn_async (NULL,
+				     (gchar **) argv,
+				     NULL,
+				     0,
+				     NULL, NULL,
+				     NULL,
+				     error);
 		goto out;
 	}
 
